==> cxxtools_2.2.1.orig.tar.gz: cxxtools-2.2.1/demo/hd.cpp <==
/*
 * Copyright (C) 2003 Tommi Maekitalo
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <iostream>
#include <fstream>
#include "cxxtools/hdstream.h"
#include "cxxtools/arg.h"
#include <algorithm>

class Hexdumper
{
    unsigned offset;

  public:
    explicit Hexdumper(unsigned offset_)
      : offset(offset_)
        { }
    void operator() (const char* file)
    {
      std::ifstream in(file);
      cxxtools::Hdostream hd;
      if (offset)
      {
        in.seekg(offset);
        hd.setOffset(offset);
      }
      hd << in.rdbuf() << std::flush;
    }
};

int main(int argc, char* argv[])
{
  cxxtools::Arg<unsigned> offset(argc, argv, 'o', 0);

  std::for_each(argv + 1, argv + argc, Hexdumper(offset));
}

==> cxxtools_3.0.0.orig.tar.gz: cxxtools-3.0/demo/hd.cpp <==
/*
 * Copyright (C) 2003 Tommi Maekitalo
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <iostream>
#include <fstream>
#include <iterator>
#include "cxxtools/hexdump.h"

int main(int argc, char* argv[])
{
    // iterate over arguments
    for (int a = 1; a < argc; ++a)
    {
        // the arguments are file names which are processed
        std::ifstream in(argv[a]);
        if (!in)
        {
            std::cerr << "failed to open file \"" << argv[a] << '"' << std::endl;
            continue;
        }

        std::cout << "file: " << argv[a] << '\n';

        // copy file content as hex dump to std::out

        // using explicit cxxtools::Hdostream:
        //     cxxtools::Hdostream hd(std::cout);
        //     hd << in.rdbuf() << std::flush;

        // or using 2 iterators:
        std::cout << cxxtools::hexDump(std::istreambuf_iterator<char>(in), std::istreambuf_iterator<char>());
    }
}
